/* Copyright (c) 2009 Corinna Vinschen <corinna@vinschen.de> */
#include <wchar.h>
#include "local.h"

#ifdef __MB_CAPABLE
#include "sb_charsets.h"
#endif /* __MB_CAPABLE */
